@@ -67,6 +67,7 @@ private:
     QvkSpezialSlider *sliderFrames;
     QvkSpezialSlider *sliderX264;
     QvkSpezialSlider *sliderOpenh264;
+    QvkSpezialSlider *sliderVaapih264;
     QvkSpezialSlider *sliderLimitOfFreeDiskSpace;
     QvkSpezialSlider *sliderShowInSystrayAlternative;
     QvkSpezialSlider *sliderHour;
@@ -135,6 +136,7 @@ private:
 
     QSoundEffect *soundEffect;
 
+
 private slots:
     void slot_preStart();
     void slot_Start();
@@ -146,8 +148,7 @@ private slots:
     void slot_Folder();
     void slot_screenCountChanged( QString, QString );
     void slot_screenCountChangedArea( QString stringText, QString stringData );
-    void slot_audioIconOnOff(bool state );
-    void slot_audioRedCross();
+//    void slot_audioIconOnOff(bool state );
     void slot_newVideoPath();
     void slot_videoFileSystemWatcherSetButtons();
     void slot_videoFileSystemWatcherSetNewPath();
@@ -160,6 +161,7 @@ private slots:
     void slot_framesReset();
     void slot_x264Reset();
     void slot_openh264Reset();
+    void slot_Vaapih264Reset();
 
     void slot_StartTimer( bool value );
     void slot_startTime();
